import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'fileName',
    width: 150,
    slots: { customRender: 'fileName' },
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { span: 7 },
  },
];
export const accountFormSchema: any[] = [
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'location',
    label: '保存位置',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'createDate',
    label: '创建时间',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'updateDate',
    label: '最近修改',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // border: 'none',
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];

export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
    colProps: { span: 8 },
  },
];
export const createFileFormSchema: FormSchema[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
  },
];
export const createTaskFormSchema: FormSchema[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '文件类型',
    component: 'Input',
    defaultValue: '任务流',
    componentProps: {
      disabled: true,
      placeholder: '请输入路径',
    },
    colProps: { lg: 24, md: 24 },
  },
];
