import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '主体名称',
    dataIndex: 'name',
    width: 120,
    slots: { customRender: 'name' },
  },
  {
    title: '描述',
    dataIndex: 'des',
    width: 120,
  },
  {
    title: '来源',
    dataIndex: 'from',
    width: 120,
  },
  {
    title: '创建者',
    dataIndex: 'creator',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 200,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 200,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
  {
    field: 'flag',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '按来源过滤',
      options: [{ label: '指标汇总表', value: '1' }],
    },
    colProps: { span: 8 },
  },
];
export const resetPasswordFormSchema: any[] = [
  {
    field: 'newPassword',
    label: '新密码',
    component: 'InputPassword',
    componentProps: {
      placeholder: '请输入8~16位，由字母和数字混合所组成的新密码',
    },
    required: true,
    // ifShow: false,
  },
];
const passwordCheck = (rule, value, callback) => {
  const pattern = /^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{8,16}$/;
  if (!pattern.test(value)) {
    callback(new Error('新密码必须为数字与字母的组合'));
  }
  callback();
};
export const accountFormSchema: any[] = [
  {
    field: 'username',
    label: '登录名',
    component: 'Input',
    // helpMessage: ['本字段演示异步验证', '不能输入带有admin的用户名'],
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
  {
    field: 'password',
    label: '密码',
    component: 'InputPassword',
    rules: [
      {
        required: true,
        message: '请输入用户密码',
      },
      { min: 8, max: 16, message: '长度在 8 到 16 个字符', trigger: 'blur' },
      {
        validator: passwordCheck,
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
  },
  {
    field: 'nickName',
    label: '昵称',
    component: 'Input',
  },
  {
    field: 'sex',
    label: '性别',
    component: 'Select',
    componentProps: {
      options: [
        { label: '男', value: '1' },
        { label: '女', value: '0' },
      ],
    },
  },
  {
    field: 'phone',
    label: '手机号码',
    component: 'Input',
    rules: [
      { required: false, message: '请输入手机号码', trigger: 'blur' },
      {
        pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/,
        message: '请输入正确的手机号码',
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'idNumber',
    label: '身份证号',
    component: 'Input',
    rules: [
      {
        required: false,
        message: '请输入身份证号',
        trigger: 'blur',
      },
      { min: 18, max: 18, message: '长度18字符', trigger: 'blur' },
    ],
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
    rules: [
      { required: false, message: '请输入邮箱地址', trigger: 'blur' },
      {
        type: 'email',
        message: '请输入正确的邮箱地址',
        trigger: ['blur', 'change'],
      },
    ],
  },
  {
    field: 'flag',
    label: '状态',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
    required: true,
  },
  {
    field: 'deptId',
    label: '所属部门',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'roleList',
    label: '角色',
    component: 'ApiSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // placeholder: '公开给',
      mode: 'multiple',
      api: getAllRoleList,
      labelField: 'roleName',
      valueField: 'businessId',
      resultField: 'data',
    },
    required: true,
  },

  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
  },
];
